<?php
/* Copyright (C) 2007 Laurent Destailleur  <eldy@users.sourceforge.net>
 * Copyright (C) 2010 Denis Martin <denimartin@hotmail.fr>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

/**
 *   	\file       htdocs/productdiscount/edit_product_discount.php
 *		\ingroup    productdiscount
 *		\brief      This page is used to add or edit a product discount
 *		\version    $Id: edit_product_discount.php,v 1.0 2010/03/20 dmartin Exp $
 *		\author		Denis Martin
 *		\remarks	Put here some comments
 */
require("./pre.inc.php");
//require_once(DOL_DOCUMENT_ROOT."/../dev/skeletons/skeleton_class.class.php");

//My includes :
require_once(DOL_DOCUMENT_ROOT."/lib/product.lib.php");
require_once(DOL_DOCUMENT_ROOT."/lib/company.lib.php");

require_once(DOL_DOCUMENT_ROOT."/product.class.php") ;
require_once(DOL_DOCUMENT_ROOT."/societe.class.php") ;
require_once(DOL_DOCUMENT_ROOT."/productdiscount.class.php") ;


// Load traductions files requiredby by page
$langs->load("companies");
$langs->load("other");
$langs->load("productdiscount") ;

// Get parameters
$socid = isset($_GET["socid"]) ? $_GET["socid"] : '' ;
$socref = isset($_GET["socref"]) ? $_GET["socref"] : '' ;
$error = array() ;
$title = 'AddProductDiscount' ;


//Parameters to fill the form again
$selectedprod = isset($_POST['product']) ? $_POST['product'] : '0' ;
$radiochecked = isset($_POST['discount_price']) ? $_POST['discount_price'] : '' ;
$discount_value = '' ;
$price_value = '' ;
$price_base_type = 'HT' ;
$action= 'add' ;

if($radiochecked == 'discount')
{
	$discount_value = isset($_POST['discount_value']) ? $_POST['discount_value'] : '' ;
}
elseif($radiochecked == 'price')
{
	$price_value = $_POST['price_value'] ;
	$price_base_type = $_POST['price_base_type'] ;
}

// Protection if external user
if ($user->societe_id > 0)
{
	//accessforbidden();
}



/*******************************************************************
* ACTIONS
*
* Put here all code to do according to value of "action" parameter
********************************************************************/

/*
 * After validation of the creation form
 */
if ($_REQUEST["action"] == 'add')
{
	$socid = isset($_POST['socid'])? $_POST['socid'] : '' ;
	if($selectedprod != 0)
	{
		$param_validate = '?entitytype=thirdparty&id=' . $socid . '&prodid=' . $selectedprod ;
		switch($radiochecked)
		{
			case '' :
				//Error : no radio button checked
				$error[] = 'PDErrorNoRadioChecked' ;
				break ;
			case 'price' :
				if($price_value != '')
				{
					//Create a new product discount with a new price
					$param_validate .= '&price=' . $price_value ;
					$param_validate .= '&price_base_type=' . $price_base_type ;
					break ;
				}
				else
				{
					//Error : no price chosen
					$error[] = 'PDErrorPriceNotFilled' ;
					break ;
				}
			case 'discount' :
				if($discount_value != '')
				{
					if($discount_value <= 100)
					{
						//Create a new product discount with a new discount
						$param_validate .= '&discount=' . $discount_value ;
					}
					else
					{
						//Error : discount over 100%
						$error[] = 'PDErrorDiscountOver100' ;
					}
					break ;
				}
				else
				{
					//Error : no discount chosen
					$error[] = 'PDErrorDiscountNotFilled' ;
					break ;
				}
		}
	}
	else
	{
		//Error : no product selected
		$error[] = 'PDErrorNoProductSelected' ;
	}
	
}

/*
 * After validation of the editing form
 */
if($_REQUEST['action'] == 'validEdit')
{
	$socid = isset($_POST['socid'])? $_POST['socid'] : '' ;
	$pdid = isset($_POST['pdid']) ? $_POST['pdid'] : '' ;
	$param_validate = '?entitytype=thirdparty&id=' . $socid . '&pdid=' . $pdid ;
	switch($radiochecked)
	{
		case '' :
			//Error : no radio button checked
			$error[] = 'PDErrorNoRadioChecked' ;
			break ;
		case 'price' :
			if($price_value != '')
			{
				//Create a new product discount with a new price
				$param_validate .= '&price=' . $price_value ;
				$param_validate .= '&price_base_type=' . $price_base_type ;
				break ;
			}
			else
			{
				//Error : no price chosen
				$error[] = 'PDErrorPriceNotFilled' ;
				break ;
			}
		case 'discount' :
			if($discount_value != '')
			{
				if($discount_value <= 100)
				{
					//Create a new product discount with a new discount
					$param_validate .= '&discount=' . $discount_value ;
				}
				else
				{
					//Error : discount over 100%
					$error[] = 'PDErrorDiscountOver100' ;
				}
				break ;
			}
			else
			{
				//Error : no discount chosen
				$error[] = 'PDErrorDiscountNotFilled' ;
				break ;
			}
		}
	
}




/***************************************************
* PAGE
*
* Put here all code to build page
****************************************************/

llxHeader('MyPageName','','');

$form=new Form($db);


//Creating thirdparty and getting details from DB
$societe = new Societe($db);


if ($socref)
{
	$result = $societe->fetch('',$socref);
	$socid = $societe->id;
}
elseif ($socid)
{
	$result = $societe->fetch($socid);
}
else
{
	print 'error' ;
}

//Preparation of tabs
$head = societe_prepare_head($societe);
//Displaying of tabs for thirdparty card
dol_fiche_head($head, 'tabProductDiscount', $langs->trans("ThirdParty"),0,'company');

// Loading Product discount to edit
if($_GET['action'] == 'edit')
{
	$title = 'EditProductDiscount' ;
	$action = 'validEdit' ;
	$productdiscount = new ProductDiscount($db) ;
	if($productdiscount->fetch($_REQUEST['pdid'], false) > 0)
	{
		if($productdiscount->discount != '')
		{
			$discount_value = $productdiscount->discount ;
			$radiochecked = 'discount' ;
		}
		elseif($productdiscount->price != '')
		{
			$price_value = price($productdiscount->price) ;
			$price_base_type = $productdiscount->price_base_type ;
			$radiochecked = 'price' ;
		}
		$product = new Product($db) ;
		if($product->fetch($productdiscount->fk_product) < 0)
		{
			$error[] = 'ErrorRecordNotFound' ;
		}
		
	}
	else
	{
		$error[] = 'PDErrorLoadingProductDiscount' ;
	}
}

// If we submitted the editing form once, only load the product linked the the product discount
// We do not load the price and discount stored in database.
if($_POST['action'] == 'validEdit')
{
	$title = 'EditProductDiscount' ;
	$action = 'validEdit' ;
	$productdiscount = new ProductDiscount($db) ;
	if($productdiscount->fetch($_REQUEST['pdid'], false) > 0)
	{
		$product = new Product($db) ;
		if($product->fetch($productdiscount->fk_product) < 0)
		{
			$error[] = 'ErrorRecordNotFound' ;
		}
		
	}
	else
	{
		$error[] = 'PDErrorLoadingProductDiscount' ;
	}
}

if($_REQUEST["action"] == 'add' && count($error) == 0)
{
	$form->form_confirm
	(
		'view_product_discount.php'.$param_validate,
		$langs->trans("CreateProductDiscount"),
		$langs->trans("ConfirmCreateProductDiscount"),
		'confirm_create',
		'',
		1, 1
	) ;
}

if($_REQUEST['action'] == 'validEdit' && count($error) == 0)
{
	$form->form_confirm
	(
		'view_product_discount.php'.$param_validate,
		$langs->trans("EditProductDiscount"),
		$langs->trans("ConfirmEditProductDiscount"),
		'confirm_edit',
		'',
		1, 1
	) ;
}

if(count($error) != 0)
{
	print '<table width="100%" class="valid">' . "\n" ;
	print '<tr class="valid_titre"><td><strong>' . $langs->trans('Error') . '</strong></td></tr>' ;
	foreach($error as $err)
	{
		print '<tr class="valid"><td>' . $form->textwithpicto($langs->trans($err), 'pouet', -1, 'warning') . '</td></tr>' ;
	}
	print '</table>' ;
}

print '<h2>'. $langs->trans($title) . '</h2>' . "\n" ;

print '<form name="add" action="'.$_SERVER["PHP_SELF"].'" method="post">' . "\n" ;
print '<input type="hidden" name="token" value="'.$_SESSION['newtoken'].'">' . "\n" ;
print '<input type="hidden" name="action" value="' . $action . '">' . "\n" ;
print '<input type="hidden" name="socid" value="'.$societe->id.'">' ."\n";
if($action == 'validEdit') print '<input type="hidden" name="pdid" value="' . $productdiscount->id . '">' . "\n" ;

print '<table class="border" width="100%">' . "\n" ;

print '<tr> <td width="20%">' . $langs->trans("Customer") . '</td> <td>' . $societe->getNomUrl(1, '', 24) . '</td> </tr>' . "\n" ;

print '<tr> <td>' . $langs->trans("Product") . '</td> <td>' ;

// If we are editing the product discount, we should not be able to change the product
if($_GET['action'] == 'edit' || $_POST['action'] == 'validEdit')
{
	print $product->getNomUrl(1, '', 0) . ' - ' . $product->libelle ;
}
else
{
	$form->select_produits($selectedprod, 'product', '', $conf->produit->limit_size, $soc->price_level) ;
}

print '</td> </tr>' . "\n" ;

print '<tr> <td> <input type="radio" name="discount_price" value="discount" class="flat" ' ;
	if($radiochecked == 'discount' || $radiochecked == ''){ print 'checked="true" ' ;}
	print '/> ' . $langs->trans("Discount") . ' <br/> ' ;
print '<input type="radio" name="discount_price" value="price" class="flat" ' ;
	if($radiochecked == 'price'){ print 'checked="true" ' ; }
	print '/> ' . $langs->trans("Price") . ' </td> ' . "\n" ;
print '<td> <input type="text" name="discount_value" size="5" class="flat" value="' . $discount_value . '"/> % <br/> ' . "\n" ;
print '<input type="text" name="price value" size="5" class="flat" value="'. $price_value . '"/> &euro; ' . "\n" ;
print '<select class="flat" name="price_base_type"><option value="HT"' ;
	if($price_base_type == 'HT') { print ' selected="true"' ; }
	print '>HT</option><option value="TTC"' ;
	if($price_base_type == 'TTC') { print ' selected="true"' ; }
	print '>TTC</option></select></td> </tr>' . "\n" ;

print '</table><br/>' . "\n" ;

print '<table class="border" width="100%">' . "\n" ;

print '<tr> <td colspan="2" align="center">' . "\n" ;
print '<a class="butAction" href="' . DOL_URL_ROOT . '/productdiscount/view_product_discount.php?entitytype=thirdparty&id=' . $societe->id . '">' . $langs->trans('Cancel') .  "</a>\n" ;
print '<input type="submit" class="butAction" value="' . $langs->trans("Confirm") . '"/> </td> </tr>' . "\n" ;

print '</table>' . "\n" ;

print '</form>' . "\n" ;


//Fin zone bleue
print '</div>' ;


// End of page
$db->close();
llxFooter('$Date: 2009/03/09 11:28:12 $ - $Revision: 1.8 $');
?>
